@@ -36,15 +36,23 @@
 #' orig <- pdf_text(news)[1]
 #'
 #' # Render pdf to jpeg/tiff image
-#' bitmap <- pdf_render_page(news, dpi = 300)
+#' bitmap <- pdf_render_page(news, dpi = 300, numeric = TRUE)
 #' tiff::writeTIFF(bitmap, "page.tiff")
 #'
 #' # Extract text from images
 #' out <- ocr("page.tiff")
 #' cat(out)
-ocr <- function(image, engine = tesseract()) {
+#'
+#' engine <- tesseract(options = list(tessedit_char_whitelist = "0123456789"))
+ocr <- function(image, engine = tesseract("eng")) {
   stopifnot(inherits(engine, "tesseract"))
-  if(is.character(image)){
+  if(inherits(image, "magick-image")){
+    image <- lapply(image, function(x){
+      tmp <- tempfile(fileext = ".tiff")
+      magick::image_write(x, tmp, format = "tiff")
+    })
+    vapply(image, ocr_file, character(1), ptr = engine, USE.NAMES = FALSE)
+  } else if(is.character(image)){
     image <- download_files(image)
     vapply(image, ocr_file, character(1), ptr = engine, USE.NAMES = FALSE)
   } else if(is.raw(image)){
@@ -59,25 +67,36 @@ ocr <- function(image, engine = tesseract()) {
 #' @param language string with language for training data. Usually defaults to `eng`
 #' @param datapath path with the training data for this language. Default uses
 #' the system library.
+#' @param options a named list with tesseract
+#' [engine options](http://www.sk-spell.sk.cx/tesseract-ocr-parameters-in-302-version)
 #' @param cache use a cached version of this training data if available
 tesseract <- local({
   store <- new.env()
-  function(language = NULL, datapath = NULL, cache = TRUE){
+  function(language = NULL, datapath = NULL, options = NULL, cache = TRUE){
     datapath <- as.character(datapath)
     language <- as.character(language)
+    options <- as.list(options)
     if(isTRUE(cache)){
-      key <- digest::digest(list(language, datapath))
+      key <- digest::digest(list(language, datapath, options))
       if(is.null(store[[key]])){
-        ptr <- tesseract_engine_internal(datapath, language)
+        ptr <- tesseract_engine(datapath, language, options)
         assign(key, ptr, store);
       }
       store[[key]]
     } else {
-      tesseract_engine_internal(datapath, language)
+      tesseract_engine(datapath, language, options)
     }
   }
 })
 
+tesseract_engine <- function(datapath, language, options){
+  engine <- tesseract_engine_internal(datapath, language)
+  for(i in seq_along(options)){
+    tesseract_engine_set_variable(engine, names(options[i]), options[[i]])
+  }
+  engine
+}
+
 download_files <- function(urls){
   vapply(urls, function(path){
     if(grepl("^https?://", path)){
